Improve this Doc

# Error: $sce:unsafe
Require a safe/trusted value

    Attempting to use an unsafe value in a safe context.

## Description

The value provided for use in a specific context was not found to be safe/trusted for use.

Angular's Strict Contextual Escaping (SCE) mode (enabled by default), requires bindings in certain contexts to result in a value that is trusted as safe for use in such a context. (e.g. loading an Angular template from a URL requires that the URL is one considered safe for loading resources.)

This helps prevent XSS and other security issues. Read more at Strict Contextual Escaping (SCE)

You may want to include the ngSanitize module to use the automatic sanitizing.